@@ -1,16 +1,17 @@
 package Geo::Coordinates::Converter;
 use strict;
 use warnings;
-use parent 'Class::Accessor::Fast';
-__PACKAGE__->mk_accessors(qw/ source current /);
+use Class::Accessor::Lite (
+    rw => [qw/ source current /],
+);
 
 use 5.008001;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Carp;
 use String::CamelCase qw( camelize );
-use UNIVERSAL::require;
+use Module::Load ();
 
 use Geo::Coordinates::Converter::Point;
 
@@ -29,7 +30,7 @@ sub new {
 
     my $converter = delete $opt{converter} || $DEFAULT_CONVERTER;
     unless (ref $converter) {
-        $converter->require or die $@;
+        Module::Load::load($converter);
         $converter = $converter->new unless ref $converter;
     }
 
@@ -62,11 +63,11 @@ sub load_format {
 
     unless (ref $format) {
         if ($format =~ s/^\+//) {
-            $format->require or die $@;
+            Module::Load::load($format);
         } else {
             my $name = $format;
             $format = sprintf '%s::Format::%s', ref $self, camelize($name);
-            $format->require or die $@;
+            Module::Load::load($format);
         }
         $format = $format->new;
     }
